# Generated by Django 3.2 on 2021-04-22 00:47

import calaccess_raw.annotations.documents
import calaccess_raw.annotations.forms
import calaccess_raw.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("calaccess_raw", "0016_auto_20200818_0542"),
    ]

    operations = [
        migrations.AlterField(
            model_name="acronymscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="addresscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="ballotmeasurescd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="cvr2campaigndisclosurecd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="cvr2lobbydisclosurecd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    ("", "Form 625: Report of Lobbying Firm"),
                    (
                        "",
                        "Form 635: Report of Lobbyist Employer or Report of Lobbying Coalition",
                    ),
                ],
                db_column="FORM_TYPE",
                db_index=True,
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=57
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712034-Cal-Format-201", start_page=71
                    ),
                ],
                help_text="Name of the source filing form or schedule",
                max_length=4,
            ),
        ),
        migrations.AlterField(
            model_name="cvr2lobbydisclosurecd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="cvr2registrationcd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    ("", "Form 601: Lobbying Firm Registration Statement"),
                    ("", "Form 602: Lobbying Firm Activity Authorization"),
                    (
                        "",
                        "Form 603: Lobbyist Employer or Lobbying Coalition Registration Statement",
                    ),
                ],
                db_column="FORM_TYPE",
                db_index=True,
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=72
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712034-Cal-Format-201", start_page=87
                    ),
                ],
                help_text="Name of the source filing form or schedule",
                max_length=10,
            ),
        ),
        migrations.AlterField(
            model_name="cvr2registrationcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="cvr2socd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    (
                        "",
                        "Form 400 (Statement of Organization (Slate Mailer Organization)): Part 3, Individuals Who Authorize Contents Of Slate Mailers",
                    ),
                    (
                        "",
                        "Form 410 (Statement of Organization (Recipient Committee)): Part 4, Type of Committee",
                    ),
                ],
                db_column="FORM_TYPE",
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2711616-MapCalFormat2Fields", start_page=38
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        end_page=46, id="2712033-Cal-Format-1-05-02", start_page=45
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        end_page=59, id="2712034-Cal-Format-201", start_page=58
                    ),
                ],
                help_text="Form type of the filing the record is included in. This must equal the form_type of the parent filing's cover (CVR) record.",
                max_length=4,
                verbose_name="form type",
            ),
        ),
        migrations.AlterField(
            model_name="cvr2socd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="cvr3verificationinfocd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="cvrcampaigndisclosurecd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="cvre530cd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[("", "Electronic Form 530: Electronic Issue Advocacy Report")],
                db_column="FORM_TYPE",
                db_index=True,
                help_text="Name of the source filing form or schedule",
                max_length=4,
                verbose_name="form type",
            ),
        ),
        migrations.AlterField(
            model_name="cvre530cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="cvrf470cd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    (
                        "",
                        "Form 470: Campaign Disclosure Statement, Short Form (Officeholders and Candidates)",
                    )
                ],
                db_column="FORM_TYPE",
                db_index=True,
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=22
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712034-Cal-Format-201", start_page=29
                    ),
                ],
                help_text="Type of Filing or Formset. The value of this column will always be equal to F470.",
                max_length=4,
            ),
        ),
        migrations.AlterField(
            model_name="cvrf470cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="cvrlobbydisclosurecd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    ("", "Form 615: Lobbyist Report"),
                    ("", "Form 625: Report of Lobbying Firm"),
                    (
                        "",
                        "Form 635: Report of Lobbyist Employer or Report of Lobbying Coalition",
                    ),
                    ("", "Form 645: Report of Person Spending $5,000 or More"),
                ],
                db_column="FORM_TYPE",
                db_index=True,
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=53
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712034-Cal-Format-201", start_page=66
                    ),
                ],
                help_text="Name of the source filing form or schedule",
                max_length=4,
            ),
        ),
        migrations.AlterField(
            model_name="cvrlobbydisclosurecd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="cvrregistrationcd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    ("", "Form 601: Lobbying Firm Registration Statement"),
                    ("", "Form 602: Lobbying Firm Activity Authorization"),
                    (
                        "",
                        "Form 603: Lobbyist Employer or Lobbying Coalition Registration Statement",
                    ),
                    ("", "Form 604: Lobbyist Certification Statement"),
                    ("", "Form 606: Notice of Termination"),
                    ("", "Form 607: Notice of Withdrawal"),
                ],
                db_column="FORM_TYPE",
                db_index=True,
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=68
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712034-Cal-Format-201", start_page=82
                    ),
                ],
                help_text="Name of the source filing form or schedule",
                max_length=4,
            ),
        ),
        migrations.AlterField(
            model_name="cvrregistrationcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="cvrsocd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="debtcd",
            name="expn_code",
            field=calaccess_raw.fields.CharField(
                blank=True,
                choices=[
                    ("CMP", "campaign paraphernalia/miscellaneous"),
                    ("CNS", "campaign consultants"),
                    ("CTB", "contribution (if nonmonetary, explain)*"),
                    ("CVC", "civic donations"),
                    ("FIL", "candidate filing/ballot feeds"),
                    ("FND", "fundraising events"),
                    ("IKD", "In-kind contribution (nonmonetary)"),
                    (
                        "IND",
                        "independent expenditure supporting/opposing others (explain)*",
                    ),
                    ("LEG", "legal defense"),
                    ("LIT", "campaign literature and mailings"),
                    ("LON", "loan"),
                    ("MBR", "member communications"),
                    ("MON", "monetary contribution"),
                    ("MTG", "meetings and appearances"),
                    ("OFC", "office expenses"),
                    ("PET", "petition circulating"),
                    ("PHO", "phone banks"),
                    ("POL", "polling and survey research"),
                    ("POS", "postage, delivery and messenger services"),
                    ("PRO", "professional services (legal, accounting)"),
                    ("PRT", "print ads"),
                    ("RAD", "radio airtime and production costs"),
                    ("RFD", "returned contributions"),
                    ("SAL", "campaign workers salaries"),
                    ("TEL", "T.V. or cable airtime and production costs"),
                    ("TRC", "candidate travel, lodging and meals (explain)"),
                    ("TRS", "staff/spouse travel, lodging and meals (explain)"),
                    (
                        "TSF",
                        "transfer between committees of the same candidate/sponsor",
                    ),
                    ("VOT", "voter registration"),
                    ("WEB", "information technology costs (internet, e-mail)"),
                    ("Fnd", "fundraising events"),
                    ("ofc", "office expenses"),
                    ("'CN", "campaign consultants"),
                    ("*", "Unknown"),
                    ("AIR", "Unknown"),
                    ("BUS", "Unknown"),
                    ("C", "Unknown"),
                    ("CAM", "Unknown"),
                    ("CC", "Unknown"),
                    ("COM", "Unknown"),
                    ("CON", "Unknown"),
                    ("CSN", "Unknown"),
                    ("DEP", "Unknown"),
                    ("EVE", "Unknown"),
                    ("F", "Unknown"),
                    ("FED", "Unknown"),
                    ("fns", "Unknown"),
                    ("G", "Unknown"),
                    ("GGG", "Unknown"),
                    ("HOT", "Unknown"),
                    ("L", "Unknown"),
                    ("LDF", "Unknown"),
                    ("MEE", "Unknown"),
                    ("N", "Unknown"),
                    ("O", "Unknown"),
                    ("OTH", "Unknown"),
                    ("P", "Unknown"),
                    ("PEN", "Unknown"),
                    ("S", "Unknown"),
                    ("SPE", "Unknown"),
                    ("STA", "Unknown"),
                    ("T", "Unknown"),
                    ("TAX", "Unknown"),
                    ("TRA", "Unknown"),
                    ("V", "Unknown"),
                    ("X", "Unknown"),
                ],
                db_column="EXPN_CODE",
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=11
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        end_page=14, id="2712034-Cal-Format-201", start_page=13
                    ),
                ],
                help_text="Expense Code",
                max_length=4,
                verbose_name="expense code",
            ),
        ),
        migrations.AlterField(
            model_name="debtcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="efsfilinglogcd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    (
                        "",
                        "Form 400: Statement of Organization (Slate Mailer Organization)",
                    ),
                    (
                        "",
                        "Form 401: Campaign Disclosure Statement (Slate Mailer Organization)",
                    ),
                    (
                        "",
                        "Form 402: Statement of Termination (Slate Mailer Organization)",
                    ),
                    ("", "Form 410: Statement of Organization (Recipient Committee)"),
                    (
                        "",
                        "Form 425: Semi-Annual Statement of No Activity (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 450: Campaign Disclosure Statement, Short Form (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 460: Campaign Disclosure Statement (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 461: Campaign Disclosure Statement (Independent Expenditure Committee & Major Donor Committee)",
                    ),
                    ("", "Form 465: Supplemental Independent Expenditure Report"),
                    ("", "Form 496: Late Independent Expenditure Report"),
                    ("", "Form 497: Late Contribution Report"),
                    ("", "Form 498: Late Payment Report (Slate Mailer Organization)"),
                    ("", "Form 601: Lobbying Firm Registration Statement"),
                    ("", "Form 602: Lobbying Firm Activity Authorization"),
                    (
                        "",
                        "Form 603: Lobbyist Employer or Lobbying Coalition Registration Statement",
                    ),
                    ("", "Form 604: Lobbyist Certification Statement"),
                    ("", "Form 606: Notice of Termination"),
                    ("", "Form 607: Notice of Withdrawal"),
                    ("", "Form 615: Lobbyist Report"),
                    ("", "Form 625: Report of Lobbying Firm"),
                    (
                        "",
                        "Form 635: Report of Lobbyist Employer or Report of Lobbying Coalition",
                    ),
                    ("", "Form 645: Report of Person Spending $5,000 or More"),
                    ("BADFORMAT 253", "Unknown"),
                    ("form", "Unknown"),
                ],
                db_column="FORM_TYPE",
                db_index=True,
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        end_page=8, id="2711624-Overview", start_page=4
                    )
                ],
                help_text="Name of the source filing form or schedule",
                max_length=250,
                verbose_name="form type",
            ),
        ),
        migrations.AlterField(
            model_name="efsfilinglogcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="expncd",
            name="expn_code",
            field=calaccess_raw.fields.CharField(
                blank=True,
                choices=[
                    ("CMP", "campaign paraphernalia/miscellaneous"),
                    ("CNS", "campaign consultants"),
                    ("CTB", "contribution (if nonmonetary, explain)*"),
                    ("CVC", "civic donations"),
                    ("FIL", "candidate filing/ballot feeds"),
                    ("FND", "fundraising events"),
                    ("IKD", "In-kind contribution (nonmonetary)"),
                    (
                        "IND",
                        "independent expenditure supporting/opposing others (explain)*",
                    ),
                    ("LEG", "legal defense"),
                    ("LIT", "campaign literature and mailings"),
                    ("LON", "loan"),
                    ("MBR", "member communications"),
                    ("MON", "monetary contribution"),
                    ("MTG", "meetings and appearances"),
                    ("OFC", "office expenses"),
                    ("PET", "petition circulating"),
                    ("PHO", "phone banks"),
                    ("POL", "polling and survey research"),
                    ("POS", "postage, delivery and messenger services"),
                    ("PRO", "professional services (legal, accounting)"),
                    ("PRT", "print ads"),
                    ("RAD", "radio airtime and production costs"),
                    ("RFD", "returned contributions"),
                    ("SAL", "campaign workers salaries"),
                    ("TEL", "T.V. or cable airtime and production costs"),
                    ("TRC", "candidate travel, lodging and meals (explain)"),
                    ("TRS", "staff/spouse travel, lodging and meals (explain)"),
                    (
                        "TSF",
                        "transfer between committees of the same candidate/sponsor",
                    ),
                    ("VOT", "voter registration"),
                    ("WEB", "information technology costs (internet, e-mail)"),
                    ("ctb", "contribution (if nonmonetary, explain)*"),
                    ("ikd", "In-kind contribution (nonmonetary)"),
                    ("Mon", "monetary contribution"),
                    ("ofc", "office expenses"),
                    ("OFc", "office expenses"),
                    ("Ofc", "office expenses"),
                    ("", "Unknown"),
                    ("*", "Unknown"),
                    ("0", "Unknown"),
                    ("001", "Unknown"),
                    ("011", "Unknown"),
                    ("200", "Unknown"),
                    ("401", "Unknown"),
                    ("ADV", "Unknown"),
                    ("ANN", "Unknown"),
                    ("APR", "Unknown"),
                    ("AUG", "Unknown"),
                    ("AUT", "Unknown"),
                    ("Ban", "Unknown"),
                    ("BAN", "Unknown"),
                    ("BOO", "Unknown"),
                    ("BOX", "Unknown"),
                    ("C", "Unknown"),
                    ("CAT", "Unknown"),
                    ("CC", "Unknown"),
                    ("CHE", "Unknown"),
                    ("CIV", "Unknown"),
                    ("CNT", "Unknown"),
                    ("CON", "Unknown"),
                    ("COP", "Unknown"),
                    ("CRE", "Unknown"),
                    ("CSN", "Unknown"),
                    ("CT", "Unknown"),
                    (",CT", "Unknown"),
                    (".CT", "Unknown"),
                    ("CTN", "Unknown"),
                    ("CVD", "Unknown"),
                    ("DAT", "Unknown"),
                    ("DEC", "Unknown"),
                    ("Dem", "Unknown"),
                    ("DIN", "Unknown"),
                    ("Don", "Unknown"),
                    ("DON", "Unknown"),
                    ("Ear", "Unknown"),
                    ("EIM", "Unknown"),
                    ("EMP", "Unknown"),
                    ("F", "Unknown"),
                    ("FAX", "Unknown"),
                    ("FDN", "Unknown"),
                    ("FED", "Unknown"),
                    ("FEE", "Unknown"),
                    ("FIN", "Unknown"),
                    ("Fun", "Unknown"),
                    ("FUN", "Unknown"),
                    ("G", "Unknown"),
                    ("GEN", "Unknown"),
                    ("GGG", "Unknown"),
                    ("GOT", "Unknown"),
                    ("IEs", "Unknown"),
                    ("IN-", "Unknown"),
                    ("Ina", "Unknown"),
                    ("INK", "Unknown"),
                    ("INS", "Unknown"),
                    ("ITE", "Unknown"),
                    ("JAN", "Unknown"),
                    ("JUL", "Unknown"),
                    ("JUN", "Unknown"),
                    ("KIC", "Unknown"),
                    ("L", "Unknown"),
                    ("LEV", "Unknown"),
                    ("Lit", "Unknown"),
                    ("LN#", "Unknown"),
                    ("LOG", "Unknown"),
                    ("M", "Unknown"),
                    ("MAI", "Unknown"),
                    ("Mar", "Unknown"),
                    ("MAR", "Unknown"),
                    ("MAY", "Unknown"),
                    ("MED", "Unknown"),
                    ("MEE", "Unknown"),
                    ("MGT", "Unknown"),
                    ("Mis", "Unknown"),
                    ("MRB", "Unknown"),
                    ("NGP", "Unknown"),
                    ("NON", "Unknown"),
                    ("NOT", "Unknown"),
                    ("NOV", "Unknown"),
                    ("O", "Unknown"),
                    ("OCT", "Unknown"),
                    (".OF", "Unknown"),
                    ("OFF", "Unknown"),
                    ("OPE", "Unknown"),
                    ("OTH", "Unknown"),
                    ("P", "Unknown"),
                    ("Pac", "Unknown"),
                    ("PAI", "Unknown"),
                    ("PAR", "Unknown"),
                    ("PAY", "Unknown"),
                    ("PEN", "Unknown"),
                    ("PMT", "Unknown"),
                    (".PO", "Unknown"),
                    ("Pos", "Unknown"),
                    ("PRE", "Unknown"),
                    ("PRI", "Unknown"),
                    ("PRP", "Unknown"),
                    ("R", "Unknown"),
                    (".Re", "Unknown"),
                    (".RE", "Unknown"),
                    ("REF", "Unknown"),
                    ("REI", "Unknown"),
                    ("RFP", "Unknown"),
                    ("S", "Unknown"),
                    ("S-A", "Unknown"),
                    ("SA", "Unknown"),
                    ("Sal", "Unknown"),
                    ("S C", "Unknown"),
                    ("S.C", "Unknown"),
                    ("SCU", "Unknown"),
                    ("SEE", "Unknown"),
                    ("SEN", "Unknown"),
                    ("SEP", "Unknown"),
                    ("S.M.", "Unknown"),
                    ("SOF", "Unknown"),
                    ("SWI", "Unknown"),
                    ("T", "Unknown"),
                    ("TAX", "Unknown"),
                    ("TB", "Unknown"),
                    ("TB,", "Unknown"),
                    ("TIC", "Unknown"),
                    ("Tor", "Unknown"),
                    ("TRA", "Unknown"),
                    ("TRF", "Unknown"),
                    ("TRV", "Unknown"),
                    ("UN", "Unknown"),
                    ("UTI", "Unknown"),
                    ("V", "Unknown"),
                    ("VEN", "Unknown"),
                    ("-VO", "Unknown"),
                    ("VOI", "Unknown"),
                    ("VOY", "Unknown"),
                    ("WI", "Unknown"),
                    ("x", "Unknown"),
                    ("X", "Unknown"),
                    ("S-6", "Unknown"),
                    ("S.M", "Unknown"),
                    ("S-4", "Unknown"),
                    ("SA:", "Unknown"),
                    ("100", "Unknown"),
                    ("RFN", "Unknown"),
                    ("REN", "Unknown"),
                    ("003", "Unknown"),
                    ("S-1", "Unknown"),
                    ("08", "Unknown"),
                ],
                db_column="EXPN_CODE",
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=11
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        end_page=14, id="2712034-Cal-Format-201", start_page=13
                    ),
                ],
                help_text="The type of expenditure",
                max_length=4,
                verbose_name="expense code",
            ),
        ),
        migrations.AlterField(
            model_name="expncd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    (
                        "F450P5",
                        "Form 450 (Campaign Disclosure Statement, Short Form (Recipient Committee)): Part 5, Payments Made",
                    ),
                    (
                        "D",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule D, Summary of Expenditures Supporting / Opposing Other Candidates, Measures and Committees",
                    ),
                    (
                        "E",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule E, Payments Made",
                    ),
                    (
                        "G",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule G, Payments Made by an Agent or Independent Contractor (on Behalf of This Committee)",
                    ),
                    (
                        "F461P5",
                        "Form 461 (Campaign Disclosure Statement (Independent Expenditure Committee & Major Donor Committee)): Part 5, Contributions (Including Loans, Forgiveness of Loans, and LoanGuarantees) and Expenditures Made",
                    ),
                    (
                        "F465P3",
                        "Form 465 (Supplemental Independent Expenditure Report): Part 3, Independent Expenditures Made",
                    ),
                    (
                        "",
                        "Form 900: Campaign Disclosure Statement (Public employee retirement board candidate)",
                    ),
                ],
                db_column="FORM_TYPE",
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=31
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712034-Cal-Format-201", start_page=42
                    ),
                ],
                help_text="Name of the source filing form or schedule",
                max_length=6,
            ),
        ),
        migrations.AlterField(
            model_name="expncd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="f495p2cd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    (
                        "",
                        "Form 450: Campaign Disclosure Statement, Short Form (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 460: Campaign Disclosure Statement (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 495: Supplemental Pre-Election Campaign Statement (Recipient Committee)",
                    ),
                ],
                db_column="FORM_TYPE",
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=26
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712034-Cal-Format-201", start_page=35
                    ),
                ],
                help_text="Name of the source filing form to which the Form 495 is attached (must equal Form_Type in CVR record)",
                max_length=4,
            ),
        ),
        migrations.AlterField(
            model_name="f495p2cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="f501502cd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    ("", "Form 501: Candidate Intention Statement"),
                    ("", "Form 502: Campaign Bank Account Statement"),
                ],
                db_column="FORM_TYPE",
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2711614-CalAccessTablesWeb", start_page=58
                    )
                ],
                help_text="Name of the source filing form or schedule",
                max_length=4,
            ),
        ),
        migrations.AlterField(
            model_name="f501502cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="f690p2cd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    ("", "Form 615: Lobbyist Report"),
                    ("", "Form 625: Report of Lobbying Firm"),
                    (
                        "",
                        "Form 635: Report of Lobbyist Employer or Report of Lobbying Coalition",
                    ),
                    ("", "Form 645: Report of Person Spending $5,000 or More"),
                ],
                db_column="FORM_TYPE",
                db_index=True,
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=58
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712034-Cal-Format-201", start_page=72
                    ),
                ],
                help_text="Name of the source filing form or schedule",
                max_length=4,
            ),
        ),
        migrations.AlterField(
            model_name="f690p2cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="fileracronymscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="fileraddresscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="filerethicsclasscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="filerfilingscd",
            name="form_id",
            field=calaccess_raw.fields.CharField(
                choices=[
                    (
                        "",
                        "Form 400: Statement of Organization (Slate Mailer Organization)",
                    ),
                    (
                        "",
                        "Form 401: Campaign Disclosure Statement (Slate Mailer Organization)",
                    ),
                    (
                        "",
                        "Form 402: Statement of Termination (Slate Mailer Organization)",
                    ),
                    ("", "Form 405: Amendment to Campaign Disclosure Statement"),
                    ("", "Form 410: Statement of Organization (Recipient Committee)"),
                    ("", "Form 415: Title Unknown"),
                    ("", "Form 416: Title Unknown"),
                    (
                        "",
                        "Form 419: Campaign Disclosure Statement, Long Form (Ballot Measure Committee)",
                    ),
                    (
                        "",
                        "Form 420: Campaign Disclosure Statement, Long Form (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 425: Semi-Annual Statement of No Activity (Recipient Committee)",
                    ),
                    ("", "Form 430: Title Unknown"),
                    (
                        "",
                        "Form 450: Campaign Disclosure Statement, Short Form (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 460: Campaign Disclosure Statement (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 461: Campaign Disclosure Statement (Independent Expenditure Committee & Major Donor Committee)",
                    ),
                    ("", "Form 465: Supplemental Independent Expenditure Report"),
                    (
                        "",
                        "Form 470: Campaign Disclosure Statement, Short Form (Officeholders and Candidates)",
                    ),
                    (
                        "",
                        "Form 490: Campaign Disclosure Statement, Long Form (Officeholders and Candidates)",
                    ),
                    (
                        "",
                        "Form 495: Supplemental Pre-Election Campaign Statement (Recipient Committee)",
                    ),
                    ("", "Form 496: Late Independent Expenditure Report"),
                    ("", "Form 497: Late Contribution Report"),
                    ("", "Form 498: Late Payment Report (Slate Mailer Organization)"),
                    ("", "Form 501: Candidate Intention Statement"),
                    ("", "Form 502: Campaign Bank Account Statement"),
                    ("", "Form 511: Paid Spokesperson Report"),
                    ("", "Electronic Form 530: Electronic Issue Advocacy Report"),
                    ("", "Form 601: Lobbying Firm Registration Statement"),
                    ("", "Form 602: Lobbying Firm Activity Authorization"),
                    (
                        "",
                        "Form 603: Lobbyist Employer or Lobbying Coalition Registration Statement",
                    ),
                    ("", "Form 604: Lobbyist Certification Statement"),
                    (
                        "",
                        "Form 605: Amendment to Registration, Lobbying Firm, Lobbyist Employer, Lobbying Coalition",
                    ),
                    ("", "Form 606: Notice of Termination"),
                    ("", "Form 607: Notice of Withdrawal"),
                    ("", "Form 615: Lobbyist Report"),
                    ("", "Form 625: Report of Lobbying Firm"),
                    (
                        "",
                        "Schedule 630: Payments Made to Lobbying Coalitions (Attachment to Form 625 or 635)",
                    ),
                    (
                        "",
                        "Form 635: Report of Lobbyist Employer or Report of Lobbying Coalition",
                    ),
                    (
                        "S635-C",
                        "Schedule 635C: Payments Received by Lobbying Coalitions",
                    ),
                    (
                        "",
                        "Schedule 640: Governmental Agencies Reporting (Attachment to Form 635 or Form 645)",
                    ),
                    ("", "Form 645: Report of Person Spending $5,000 or More"),
                    ("", "Form 690: Amendment to Lobbying Disclosure Report"),
                    ("", "Form 700: Statement of Economic Interest"),
                    (
                        "",
                        "Form 900: Campaign Disclosure Statement (Public employee retirement board candidate)",
                    ),
                    ("F111", "Unknown"),
                    ("F410 AT", "Unknown"),
                    ("F410ATR", "Unknown"),
                    ("F421", "Unknown"),
                    ("F440", "Unknown"),
                    (
                        "F470S",
                        "Form 470: Campaign Disclosure Statement, Short Form (Officeholders and Candidates)",
                    ),
                    ("F480", "Unknown"),
                    ("F500", "Unknown"),
                    (
                        "F501502",
                        "Forms 501 and/or 502 (Candidate Intention and/or Bank Account Statements)",
                    ),
                    ("F555", "Unknown"),
                    ("F666", "Unknown"),
                    ("F777", "Unknown"),
                    ("F888", "Unknown"),
                    ("F999", "Unknown"),
                ],
                db_column="FORM_ID",
                db_index=True,
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2711614-CalAccessTablesWeb", start_page=65
                    )
                ],
                help_text="Form identification code",
                max_length=7,
                verbose_name="form type",
            ),
        ),
        migrations.AlterField(
            model_name="filerfilingscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="filerinterestscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="filerlinkscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="filernamecd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="filerscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="filerstatustypescd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="filertofilertypecd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="filertypeperiodscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="filerxrefcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="filingperiodcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="filingscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="grouptypescd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="hdrcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="headercd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="imagelinkscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lattcd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    (
                        "",
                        "Schedule 630: Payments Made to Lobbying Coalitions (Attachment to Form 625 or 635)",
                    ),
                    (
                        "S635-C",
                        "Schedule 635C: Payments Received by Lobbying Coalitions",
                    ),
                    (
                        "",
                        "Schedule 640: Governmental Agencies Reporting (Attachment to Form 635 or Form 645)",
                    ),
                ],
                db_column="FORM_TYPE",
                db_index=True,
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2711616-MapCalFormat2Fields", start_page=52
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=65
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712034-Cal-Format-201", start_page=79
                    ),
                ],
                help_text="Name of the source filing form or schedule",
                max_length=6,
            ),
        ),
        migrations.AlterField(
            model_name="lattcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lccmcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="legislativesessionscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lempcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lexpcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="loancd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyamendmentscd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    ("", "Form 601: Lobbying Firm Registration Statement"),
                    (
                        "",
                        "Form 603: Lobbyist Employer or Lobbying Coalition Registration Statement",
                    ),
                ],
                db_column="FORM_TYPE",
                db_index=True,
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=74
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712034-Cal-Format-201", start_page=88
                    ),
                ],
                help_text="Name of the source filing form or schedule",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="lobbyamendmentscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyingchglogcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistcontributions1cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistcontributions2cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistcontributions3cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistemplobbyist1cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistemplobbyist2cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistemployer1cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistemployer2cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistemployer3cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistemployerfirms1cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistemployerfirms2cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistemployerhistorycd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistfirm1cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistfirm2cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistfirm3cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistfirmemployer1cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistfirmemployer2cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistfirmhistorycd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistfirmlobbyist1cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lobbyistfirmlobbyist2cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lookupcodescd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lothcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="lpaycd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="namescd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="rawdatafile",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="rawdataversion",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="rcptcd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    ("", "Electronic Form 530: Electronic Issue Advocacy Report"),
                    (
                        "",
                        "Form 900: Campaign Disclosure Statement (Public employee retirement board candidate)",
                    ),
                    (
                        "F401A",
                        "Form 401 (Campaign Disclosure Statement (Slate Mailer Organization)): Schedule A, Payments Received",
                    ),
                    (
                        "A",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule A, Monetary Contributions Received",
                    ),
                    (
                        "A-1",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule A-1, Contributions Transferred to Special Election Commitee",
                    ),
                    (
                        "C",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule C, Non-Monetary Contributions Received",
                    ),
                    (
                        "I",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule I, Miscellanous increases to cash",
                    ),
                    (
                        "F496P3",
                        "Form 496 (Late Independent Expenditure Report): Part 3, Contributions > $100 Received",
                    ),
                ],
                db_column="FORM_TYPE",
                db_index=True,
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=29
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712034-Cal-Format-201", start_page=37
                    ),
                ],
                help_text="Name of the source filing form or schedule",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="rcptcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="receivedfilingscd",
            name="form_id",
            field=calaccess_raw.fields.CharField(
                blank=True,
                choices=[
                    (
                        "",
                        "Form 400: Statement of Organization (Slate Mailer Organization)",
                    ),
                    (
                        "",
                        "Form 401: Campaign Disclosure Statement (Slate Mailer Organization)",
                    ),
                    (
                        "",
                        "Form 402: Statement of Termination (Slate Mailer Organization)",
                    ),
                    ("", "Form 410: Statement of Organization (Recipient Committee)"),
                    (
                        "",
                        "Form 425: Semi-Annual Statement of No Activity (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 450: Campaign Disclosure Statement, Short Form (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 460: Campaign Disclosure Statement (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 461: Campaign Disclosure Statement (Independent Expenditure Committee & Major Donor Committee)",
                    ),
                    ("", "Form 465: Supplemental Independent Expenditure Report"),
                    ("", "Form 496: Late Independent Expenditure Report"),
                    ("", "Form 497: Late Contribution Report"),
                    ("", "Form 498: Late Payment Report (Slate Mailer Organization)"),
                    ("", "Form 601: Lobbying Firm Registration Statement"),
                    ("", "Form 602: Lobbying Firm Activity Authorization"),
                    (
                        "",
                        "Form 603: Lobbyist Employer or Lobbying Coalition Registration Statement",
                    ),
                    ("", "Form 604: Lobbyist Certification Statement"),
                    ("", "Form 606: Notice of Termination"),
                    ("", "Form 607: Notice of Withdrawal"),
                    ("", "Form 615: Lobbyist Report"),
                    ("", "Form 625: Report of Lobbying Firm"),
                    (
                        "",
                        "Form 635: Report of Lobbyist Employer or Report of Lobbying Coalition",
                    ),
                    ("", "Form 645: Report of Person Spending $5,000 or More"),
                ],
                db_column="FORM_ID",
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        end_page=8, id="2711624-Overview", start_page=4
                    )
                ],
                help_text="Form identification code",
                max_length=7,
                verbose_name="form identification code",
            ),
        ),
        migrations.AlterField(
            model_name="receivedfilingscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="reportscd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="s401cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="s496cd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                blank=True,
                choices=[("", "Form 496: Late Independent Expenditure Report")],
                db_column="FORM_TYPE",
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=40
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712034-Cal-Format-201", start_page=53
                    ),
                ],
                help_text="Name of the source filing form or schedule",
                max_length=4,
            ),
        ),
        migrations.AlterField(
            model_name="s496cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="s497cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="s498cd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="smrycd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    (
                        "",
                        "Form 401: Campaign Disclosure Statement (Slate Mailer Organization)",
                    ),
                    (
                        "F401A",
                        "Form 401 (Campaign Disclosure Statement (Slate Mailer Organization)): Schedule A, Payments Received",
                    ),
                    (
                        "F401B",
                        "Form 401 (Campaign Disclosure Statement (Slate Mailer Organization)): Schedule B, Payments Made",
                    ),
                    (
                        "F401B-1",
                        "Form 401 (Campaign Disclosure Statement (Slate Mailer Organization)): Schedule B-1, Payments Made by Agent or Independent Contractor",
                    ),
                    (
                        "",
                        "Form 450: Campaign Disclosure Statement, Short Form (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 460: Campaign Disclosure Statement (Recipient Committee)",
                    ),
                    (
                        "A",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule A, Monetary Contributions Received",
                    ),
                    (
                        "B1",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule B, Part 1, Loans Received",
                    ),
                    (
                        "B2",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule B, Part 2, Loan Guarantors",
                    ),
                    (
                        "B3",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule B, Part 3, Outstanding Balance",
                    ),
                    (
                        "C",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule C, Non-Monetary Contributions Received",
                    ),
                    (
                        "D",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule D, Summary of Expenditures Supporting / Opposing Other Candidates, Measures and Committees",
                    ),
                    (
                        "E",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule E, Payments Made",
                    ),
                    (
                        "F",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule F, Accrued Expenses (Unpaid Bills)",
                    ),
                    (
                        "G",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule G, Payments Made by an Agent or Independent Contractor (on Behalf of This Committee)",
                    ),
                    (
                        "H",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule H, Loans Made to Others",
                    ),
                    (
                        "H1",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule H, Part 1, Loans Made",
                    ),
                    (
                        "H2",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule H, Part 2, Repayments Rcvd",
                    ),
                    (
                        "H3",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule H, Part 3, Outstanding Loans",
                    ),
                    (
                        "I",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule I, Miscellanous increases to cash",
                    ),
                    (
                        "",
                        "Form 461: Campaign Disclosure Statement (Independent Expenditure Committee & Major Donor Committee)",
                    ),
                    ("", "Form 465: Supplemental Independent Expenditure Report"),
                    ("", "Form 625: Report of Lobbying Firm"),
                    (
                        "F625P2",
                        "Form 625 (Report of Lobbying Firm): Part 2, Payments Received in Connection with Lobbying Activity",
                    ),
                    (
                        "F625P3A",
                        "Form 625 (Report of Lobbying Firm): Part 3, Payments Made In Connection With Lobbying Activities, Section A, Activity Expenses",
                    ),
                    (
                        "F625P3B",
                        "Form 625 (Report of Lobbying Firm): Part 3, Payments Made In Connection With Lobbying Activities, Section B, Payments Made",
                    ),
                    (
                        "",
                        "Form 635: Report of Lobbyist Employer or Report of Lobbying Coalition",
                    ),
                    (
                        "F635P3A",
                        "Form 635 (Report of Lobbyist Employer or Report of Lobbying Coalition): Part 3, Payments Made in Connection with Lobbying Activities, Section A, Payments To In-house Employee Lobbyists",
                    ),
                    (
                        "F635P3B",
                        "Form 635 (Report of Lobbyist Employer or Report of Lobbying Coalition): Part 3, Payments Made in Connection with Lobbying Activities, Section B, Payments To Lobbying Firms",
                    ),
                    (
                        "F635P3C",
                        "Form 635 (Report of Lobbyist Employer or Report of Lobbying Coalition): Part 3, Payments Made in Connection with Lobbying Activities, Section C, Activity Expenses",
                    ),
                    (
                        "F635P3D",
                        "Form 635 (Report of Lobbyist Employer or Report of Lobbying Coalition): Part 3, Payments Made in Connection with Lobbying Activities, Section D, Other Payments to Influence Legislative or Administrative Action",
                    ),
                    (
                        "F635P3E",
                        "Form 635 (Report of Lobbyist Employer or Report of Lobbying Coalition): Part 3, Payments Made in Connection with Lobbying Activities, Section E, Payments in Connection with Administrative Testimony in Ratemaking Proceedings Before The California Public Utilities Commission",
                    ),
                    (
                        "",
                        "Schedule 640: Governmental Agencies Reporting (Attachment to Form 635 or Form 645)",
                    ),
                    ("", "Form 645: Report of Person Spending $5,000 or More"),
                    (
                        "F645P2A",
                        "Form 645 (Report of Person Spending $5,000 or More): Part 2, Payments Made this Period, Section A, Activity Expenses",
                    ),
                    (
                        "F645P2B",
                        "Form 645 (Report of Person Spending $5,000 or More): Part 2, Payments Made this Period, Section B, Other Payments to Influence Legislative or Administrative Action",
                    ),
                    (
                        "F645P2C",
                        "Form 645 (Report of Person Spending $5,000 or More): Part 2, Payments Made this Period, Section C, Payments in Connection with Administrative Testimony in Ratemaking Proceedings Before the California Public Utilities Commission",
                    ),
                    (
                        "",
                        "Form 900: Campaign Disclosure Statement (Public employee retirement board candidate)",
                    ),
                    (
                        "401A",
                        calaccess_raw.annotations.forms.FilingFormSection(
                            db_value="F401A",
                            documentcloud_id=None,
                            end_page="7",
                            form=calaccess_raw.annotations.forms.FilingForm(
                                db_value="",
                                description="Form 401 is filed by slate mailer organizations to disclose payments made and received in connection with producing slate mailers.",
                                documentcloud_id="2781366-401-2005-01",
                                group="CAMPAIGN",
                                id="F401",
                                title="Campaign Disclosure Statement (Slate Mailer Organization)",
                            ),
                            id="A",
                            start_page="5",
                            title="Schedule A, Payments Received",
                        ),
                    ),
                    (
                        "401B",
                        calaccess_raw.annotations.forms.FilingFormSection(
                            db_value="F401B",
                            documentcloud_id=None,
                            end_page="9",
                            form=calaccess_raw.annotations.forms.FilingForm(
                                db_value="",
                                description="Form 401 is filed by slate mailer organizations to disclose payments made and received in connection with producing slate mailers.",
                                documentcloud_id="2781366-401-2005-01",
                                group="CAMPAIGN",
                                id="F401",
                                title="Campaign Disclosure Statement (Slate Mailer Organization)",
                            ),
                            id="B",
                            start_page="8",
                            title="Schedule B, Payments Made",
                        ),
                    ),
                    (
                        "401B-1",
                        calaccess_raw.annotations.forms.FilingFormSection(
                            db_value="F401B-1",
                            documentcloud_id=None,
                            end_page="",
                            form=calaccess_raw.annotations.forms.FilingForm(
                                db_value="",
                                description="Form 401 is filed by slate mailer organizations to disclose payments made and received in connection with producing slate mailers.",
                                documentcloud_id="2781366-401-2005-01",
                                group="CAMPAIGN",
                                id="F401",
                                title="Campaign Disclosure Statement (Slate Mailer Organization)",
                            ),
                            id="B-1",
                            start_page="10",
                            title="Schedule B-1, Payments Made by Agent or Independent Contractor",
                        ),
                    ),
                ],
                db_column="FORM_TYPE",
                db_index=True,
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2711616-MapCalFormat2Fields", start_page=86
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        end_page=28, id="2712033-Cal-Format-1-05-02", start_page=27
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        end_page=60, id="2712033-Cal-Format-1-05-02", start_page=59
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        end_page=37, id="2712034-Cal-Format-201", start_page=36
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        end_page=74, id="2712034-Cal-Format-201", start_page=73
                    ),
                ],
                help_text="Name of the source filing form or schedule",
                max_length=8,
            ),
        ),
        migrations.AlterField(
            model_name="smrycd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="spltcd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="textmemocd",
            name="form_type",
            field=calaccess_raw.fields.CharField(
                choices=[
                    (
                        "",
                        "Form 401: Campaign Disclosure Statement (Slate Mailer Organization)",
                    ),
                    ("", "Form 405: Amendment to Campaign Disclosure Statement"),
                    ("", "Form 410: Statement of Organization (Recipient Committee)"),
                    (
                        "",
                        "Form 425: Semi-Annual Statement of No Activity (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 450: Campaign Disclosure Statement, Short Form (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 460: Campaign Disclosure Statement (Recipient Committee)",
                    ),
                    (
                        "",
                        "Form 461: Campaign Disclosure Statement (Independent Expenditure Committee & Major Donor Committee)",
                    ),
                    ("", "Form 465: Supplemental Independent Expenditure Report"),
                    ("", "Form 496: Late Independent Expenditure Report"),
                    ("", "Form 497: Late Contribution Report"),
                    ("", "Form 498: Late Payment Report (Slate Mailer Organization)"),
                    ("", "Form 601: Lobbying Firm Registration Statement"),
                    ("", "Form 602: Lobbying Firm Activity Authorization"),
                    (
                        "",
                        "Form 603: Lobbyist Employer or Lobbying Coalition Registration Statement",
                    ),
                    ("", "Form 604: Lobbyist Certification Statement"),
                    (
                        "",
                        "Form 605: Amendment to Registration, Lobbying Firm, Lobbyist Employer, Lobbying Coalition",
                    ),
                    ("", "Form 606: Notice of Termination"),
                    ("", "Form 607: Notice of Withdrawal"),
                    ("", "Form 615: Lobbyist Report"),
                    ("", "Form 625: Report of Lobbying Firm"),
                    (
                        "",
                        "Form 635: Report of Lobbyist Employer or Report of Lobbying Coalition",
                    ),
                    ("", "Form 645: Report of Person Spending $5,000 or More"),
                    (
                        "",
                        "Schedule 630: Payments Made to Lobbying Coalitions (Attachment to Form 625 or 635)",
                    ),
                    (
                        "S635-C",
                        "Schedule 635C: Payments Received by Lobbying Coalitions",
                    ),
                    (
                        "",
                        "Schedule 640: Governmental Agencies Reporting (Attachment to Form 635 or Form 645)",
                    ),
                    (
                        "410",
                        "Form 410: Statement of Organization (Recipient Committee)",
                    ),
                    (
                        "460",
                        "Form 460: Campaign Disclosure Statement (Recipient Committee)",
                    ),
                    (
                        "461",
                        "Form 461: Campaign Disclosure Statement (Independent Expenditure Committee & Major Donor Committee)",
                    ),
                    ("465", "Form 465: Supplemental Independent Expenditure Report"),
                    ("496", "Form 496: Late Independent Expenditure Report"),
                    ("497", "Form 497: Late Contribution Report"),
                    (
                        "497P1",
                        "Form 497 (Late Contribution Report): Part 1, Contributions Received",
                    ),
                    (
                        "497P2",
                        "Form 497 (Late Contribution Report): Part 2, Contributions Made",
                    ),
                    (
                        "F401A",
                        "Form 401 (Campaign Disclosure Statement (Slate Mailer Organization)): Schedule A, Payments Received",
                    ),
                    (
                        "F401B",
                        "Form 401 (Campaign Disclosure Statement (Slate Mailer Organization)): Schedule B, Payments Made",
                    ),
                    (
                        "F401B-1",
                        "Form 401 (Campaign Disclosure Statement (Slate Mailer Organization)): Schedule B-1, Payments Made by Agent or Independent Contractor",
                    ),
                    (
                        "F450P5",
                        "Form 450 (Campaign Disclosure Statement, Short Form (Recipient Committee)): Part 5, Payments Made",
                    ),
                    (
                        "F461P1",
                        "Form 461 (Campaign Disclosure Statement (Independent Expenditure Committee & Major Donor Committee)): Part 1, Name and Address of Filer",
                    ),
                    (
                        "F461P2",
                        "Form 461 (Campaign Disclosure Statement (Independent Expenditure Committee & Major Donor Committee)): Part 2, Nature and Interests of Filer",
                    ),
                    (
                        "F461P5",
                        "Form 461 (Campaign Disclosure Statement (Independent Expenditure Committee & Major Donor Committee)): Part 5, Contributions (Including Loans, Forgiveness of Loans, and LoanGuarantees) and Expenditures Made",
                    ),
                    (
                        "F465P3",
                        "Form 465 (Supplemental Independent Expenditure Report): Part 3, Independent Expenditures Made",
                    ),
                    (
                        "F496P3",
                        "Form 496 (Late Independent Expenditure Report): Part 3, Contributions > $100 Received",
                    ),
                    (
                        "F497P1",
                        "Form 497 (Late Contribution Report): Part 1, Contributions Received",
                    ),
                    (
                        "F497P2",
                        "Form 497 (Late Contribution Report): Part 2, Contributions Made",
                    ),
                    (
                        "F498-A",
                        "Form 498 (Late Payment Report (Slate Mailer Organization)): Part A, Late Payments Attributed To",
                    ),
                    (
                        "F498-R",
                        "Form 498 (Late Payment Report (Slate Mailer Organization)): Part R, Late Payments Received From",
                    ),
                    (
                        "F601P2A",
                        "Form 601 (Lobbying Firm Registration Statement): Part 2, Section A, Lobbyist Employers",
                    ),
                    (
                        "F601P2B",
                        "Form 601 (Lobbying Firm Registration Statement): Part 2, Section B, Subcontracted Clients",
                    ),
                    (
                        "F615P1",
                        "Form 615 (Lobbyist Report): Part 1, Activity Expenses Paid, Incurred, Arranged or Provided by the Lobbyist",
                    ),
                    (
                        "F615P2",
                        "Form 615 (Lobbyist Report): Part 2, Campaign Contributions Made or Delivered",
                    ),
                    (
                        "F625P2",
                        "Form 625 (Report of Lobbying Firm): Part 2, Payments Received in Connection with Lobbying Activity",
                    ),
                    (
                        "F625P3A",
                        "Form 625 (Report of Lobbying Firm): Part 3, Payments Made In Connection With Lobbying Activities, Section A, Activity Expenses",
                    ),
                    (
                        "F625P3B",
                        "Form 625 (Report of Lobbying Firm): Part 3, Payments Made In Connection With Lobbying Activities, Section B, Payments Made",
                    ),
                    (
                        "F625P4B",
                        "Form 625 (Report of Lobbying Firm): Part 4, Campaign Contributions Made",
                    ),
                    (
                        "S635",
                        "Form 635: Report of Lobbyist Employer or Report of Lobbying Coalition",
                    ),
                    (
                        "F635P3B",
                        "Form 635 (Report of Lobbyist Employer or Report of Lobbying Coalition): Part 3, Payments Made in Connection with Lobbying Activities, Section B, Payments To Lobbying Firms",
                    ),
                    (
                        "F635P3C",
                        "Form 635 (Report of Lobbyist Employer or Report of Lobbying Coalition): Part 3, Payments Made in Connection with Lobbying Activities, Section C, Activity Expenses",
                    ),
                    (
                        "F635P4B",
                        "Form 635 (Report of Lobbyist Employer or Report of Lobbying Coalition): Part 4, Campaign Contributions Made",
                    ),
                    (
                        "F645P2A",
                        "Form 645 (Report of Person Spending $5,000 or More): Part 2, Payments Made this Period, Section A, Activity Expenses",
                    ),
                    (
                        "F645P3B",
                        "Form 645 (Report of Person Spending $5,000 or More): Part 3, Campaign Contributions Made",
                    ),
                    ("S497", "Form 497: Late Contribution Report"),
                    (
                        "S635C",
                        "Schedule 635C: Payments Received by Lobbying Coalitions",
                    ),
                    ("A", "Schedule A of any form (e.g., Forms 401 or 460)"),
                    ("A4", "Schedule A of any form (e.g., Forms 401 or 460)"),
                    ("A6", "Schedule A of any form (e.g., Forms 401 or 460)"),
                    ("B", "Schedule B of any form (e.g., Forms 401 or 460)"),
                    ("B1", "Schedule B, Part 1 of Forms 401 or 460"),
                    ("B2", "Schedule B, Part 2 of Forms 401 or 460"),
                    ("B3", "Schedule B, Part 3 of Forms 401 or 460"),
                    ("C", "Schedule C of any form (e.g., Forms 401 or F460)"),
                    ("COMMENTS", "Possibly comments by FPPC for any form?"),
                    ("CVR", "Cover page for any form (e.g., Forms 460, 461 or 497)"),
                    ("D", "Schedule D of any form (e.g., Forms 401, 460 or 461)"),
                    (
                        "DEBTF",
                        "Form 460 (Campaign Disclosure Statement (Recipient Committee)): Schedule F, Accrued Expenses (Unpaid Bills)",
                    ),
                    ("E", "Schedule E of any form (e.g., Forms 460, 461 or 465)"),
                    ("EXPNT", "Expenditures outlined on any form (e.g. Form 460)"),
                    ("F", "Schedule F of any form (e.g., Form 460)"),
                    ("G", "Schedule G of any form (e.g., Form 460)"),
                    ("H", "Schedule H of any form (e.g., Form 460)"),
                    ("H1", "Schedule H, Part 1 of any form (e.g., Form 460)"),
                    ("H2", "Schedule H2, Part 2 of any form (e.g., Form 460)"),
                    ("H3", "Schedule H3, Part 3 of any form (e.g., Form 460)"),
                    ("I", "Schedule I of any form (e.g., Form 460)"),
                    ("PT5", "Part 5 of any form (e.g., Form 461"),
                    ("RCPTB1", "Schedule B, Part 1 of any form (e.g., Form 460"),
                    ("RCPTC", "Schedule C of any form (e.g., Form 460)"),
                    ("RCPTI", "Schedule I of any form (e.g., Form 460)"),
                    ("SCH A", "Schedule A of any form (e.g., Form 460)"),
                    ("SF", "Schedule F of any form (e.g., Form 460)"),
                    ("SPLT", "A memo that applies to multiple items?"),
                    ("SMRY", "Summary section of any form (e.g., Form 460)"),
                    ("SUM", "Summary section of any form (e.g., Form 460)"),
                    ("SUMMARY", "Summary section of any form (e.g., Form 460)"),
                ],
                db_column="FORM_TYPE",
                db_index=True,
                documentcloud_pages=[
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2711616-MapCalFormat2Fields", start_page=90
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712034-Cal-Format-201", start_page=16
                    ),
                    calaccess_raw.annotations.documents.DocumentCloud(
                        id="2712033-Cal-Format-1-05-02", start_page=13
                    ),
                ],
                help_text="Name of the source filing form or schedule",
                max_length=8,
                verbose_name="form type",
            ),
        ),
        migrations.AlterField(
            model_name="textmemocd",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]
