# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-08-04 17:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("calaccess_raw", "0003_auto_20160804_1443"),
    ]

    operations = [
        migrations.AddField(
            model_name="rawdataversion",
            name="clean_zip_size",
            field=models.BigIntegerField(
                help_text="The size of the zip containing all cleaned raw data files and error logs.",
                null=True,
                verbose_name="clean zip size",
            ),
        ),
        migrations.AddField(
            model_name="rawdataversion",
            name="download_zip_size",
            field=models.BigIntegerField(
                help_text="The actual size of the downloaded CAL-ACCESS zip after the downloaded completed.",
                null=True,
                verbose_name="downloaded zip size",
            ),
        ),
        migrations.AlterField(
            model_name="rawdataversion",
            name="expected_size",
            field=models.BigIntegerField(
                help_text="The expected size of the downloaded CAL-ACCESS zip, as specified in the content-length field in HTTP response header.",
                verbose_name="expected downloaded zip size",
            ),
        ),
    ]
